@@ -26,7 +26,23 @@ class UserRegistrationSerializer(serializers.ModelSerializer):
                 },
             }
 
-    def validate_password(self, value):
+    @staticmethod
+    def validate_username(value):
+        """
+        Make sure that no user with this natural key exists.
+        This can be used to make usernames case-insensitive, e.g.,
+        disallow the registration of two different usernames which
+        are equal but with different case.
+        """
+        try:
+            user = get_user_model().objects.get_by_natural_key(value)
+        except get_user_model().DoesNotExist:
+            return value
+        else:
+            raise ValidationError('already exists')
+
+    @staticmethod
+    def validate_password(value):
         if len(value) < 6:
             raise ValidationError('password too short')
         return value
